@@ -34,10 +34,11 @@ static ServiceRole services[] = {
 	{ "acct",                   GST_ROLE_SYSTEM_MONITORING },
 	{ "acpid",                  GST_ROLE_POWER_MANAGEMENT },
 	{ "alsa",                   GST_ROLE_AUDIO_MANAGEMENT },
+	{ "alsasound",              GST_ROLE_AUDIO_MANAGEMENT },
 	{ "alsa-utils",             GST_ROLE_AUDIO_MANAGEMENT },
+	{ "am-utils",               GST_ROLE_AUTOMOUNTER },
 	{ "amavis",                 GST_ROLE_ANTIVIRUS },
 	{ "amavis-ng",              GST_ROLE_ANTIVIRUS },
-	{ "am-utils",               GST_ROLE_AUTOMOUNTER },
 	{ "anacron",                GST_ROLE_COMMAND_SCHEDULER },
 	{ "apache",                 GST_ROLE_WEB_SERVER },
 	{ "apache-perl",            GST_ROLE_WEB_SERVER },
@@ -51,22 +52,26 @@ static ServiceRole services[] = {
 	{ "aumix",                  GST_ROLE_AUDIO_MANAGEMENT },
 	{ "autofs",                 GST_ROLE_AUTOMOUNTER },
 	{ "avahi-daemon",           GST_ROLE_RENDEZVOUS },
+	{ "avahi-dnsconfd",         GST_ROLE_RENDEZVOUS },
 	{ "backuppc",               GST_ROLE_REMOTE_BACKUP },
-	{ "bind9",                  GST_ROLE_DNS },
 	{ "bind",                   GST_ROLE_DNS },
+	{ "bind9",                  GST_ROLE_DNS },
 	{ "bluetooth",              GST_ROLE_BLUETOOTH_MANAGEMENT },
 	{ "bpalogin",               GST_ROLE_TELSTRA_BIGPOND_NETWORK_CLIENT },
 	{ "brltty",                 GST_ROLE_BRAILLE_DISPLAY_MANAGEMENT },
 	{ "capiutils",              GST_ROLE_ISDN_MANAGEMENT },
 	{ "cherokee",               GST_ROLE_WEB_SERVER },
 	{ "clamav-daemon",          GST_ROLE_ANTIVIRUS },
+	{ "clamav-milter",          GST_ROLE_ANTIVIRUS },
+	{ "clamd",                  GST_ROLE_ANTIVIRUS },
 	{ "clvm",                   GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "cman",                   GST_ROLE_CLUSTER_MANAGEMENT },
-	{ "courier-authdaemon",     GST_ROLE_MTA_AUTH },
 	{ "courier",                GST_ROLE_MTA },
+	{ "courier-authdaemon",     GST_ROLE_MTA_AUTH },
 	{ "courier-mta",            GST_ROLE_MTA },
-	{ "crond",                  GST_ROLE_COMMAND_SCHEDULER },
 	{ "cron",                   GST_ROLE_COMMAND_SCHEDULER },
+	{ "crond",                  GST_ROLE_COMMAND_SCHEDULER },
+	{ "cups",                   GST_ROLE_PRINTER_SERVICE },
 	{ "cupsd",                  GST_ROLE_PRINTER_SERVICE },
 	{ "cupsys",                 GST_ROLE_PRINTER_SERVICE },
 	{ "dbus",                   GST_ROLE_DBUS },
@@ -78,15 +83,15 @@ static ServiceRole services[] = {
 	{ "eagle-usb",              GST_ROLE_EAGLE_USB_MODEMS_MANAGEMENT },
 	{ "etc-setserial",          GST_ROLE_SERIAL_PORTS_MANAGEMENT },
 	{ "evms",                   GST_ROLE_LVM_MANAGEMENT },
-	{ "exim4",                  GST_ROLE_MTA },
 	{ "exim",                   GST_ROLE_MTA },
+	{ "exim4",                  GST_ROLE_MTA },
 	{ "fcron",                  GST_ROLE_COMMAND_SCHEDULER },
 	{ "festival",               GST_ROLE_SPEECH_SYNTHESIS },
 	{ "fetchmail",              GST_ROLE_MAIL_FETCHER },
 	{ "ftpd",                   GST_ROLE_FILE_SERVER_FTP },
 	{ "gdm",                    GST_ROLE_DISPLAY_MANAGER },
-	{ "gfs2-tools",             GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "gfs-tools",              GST_ROLE_CLUSTER_MANAGEMENT },
+	{ "gfs2-tools",             GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "gnbd-client",            GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "gnbd-server",            GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "hdparm",                 GST_ROLE_HDD_MANAGEMENT },
@@ -95,6 +100,7 @@ static ServiceRole services[] = {
 	{ "hplip",                  GST_ROLE_PRINTER_SERVICE },
 	{ "httpd",                  GST_ROLE_WEB_SERVER },
 	{ "inetd",                  GST_ROLE_NETWORK },
+	{ "iptables",               GST_ROLE_FIREWALL_MANAGEMENT },
 	{ "ipvsadm",                GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "irda",                   GST_ROLE_INFRARED_MANAGEMENT },
 	{ "irda-setup",             GST_ROLE_INFRARED_MANAGEMENT },
@@ -104,6 +110,7 @@ static ServiceRole services[] = {
 	{ "kdm",                    GST_ROLE_DISPLAY_MANAGER },
 	{ "keepalived",             GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "klogd",                  GST_ROLE_SYSTEM_LOGGER },
+	{ "lighttpd",               GST_ROLE_WEB_SERVER },
 	{ "lm-sensors",             GST_ROLE_HARDWARE_MONITORING },
 	{ "lpd",                    GST_ROLE_PRINTER_SERVICE },
 	{ "lpdng",                  GST_ROLE_PRINTER_SERVICE },
@@ -113,14 +120,17 @@ static ServiceRole services[] = {
 	{ "mailscanner",            GST_ROLE_ANTIVIRUS },
 	{ "mdadm",                  GST_ROLE_RAID_MANAGEMENT },
 	{ "mdadm-raid",             GST_ROLE_RAID_MANAGEMENT },
+	{ "messagebus",             GST_ROLE_DBUS },
 	{ "metalog",                GST_ROLE_SYSTEM_LOGGER },
 	{ "mgetty-fax",             GST_ROLE_FAX_MANAGEMENT },
+	{ "mksd",                   GST_ROLE_ANTIVIRUS },
 	{ "muddleftpd",             GST_ROLE_FILE_SERVER_FTP },
 	{ "multipath-tools",        GST_ROLE_LVM_MANAGEMENT },
 	{ "mysql",                  GST_ROLE_DATABASE_SERVER },
 	{ "mysql-ndb",              GST_ROLE_DATABASE_SERVER },
 	{ "mysql-ndb-mgm",          GST_ROLE_DATABASE_SERVER },
 	{ "nagios",                 GST_ROLE_SECURITY_AUDITING },
+	{ "named",                  GST_ROLE_DNS },
 	{ "nbd-client",             GST_ROLE_DISK_CLIENT },
 	{ "nbd-server",             GST_ROLE_DISK_SERVER },
 	{ "nessusd",                GST_ROLE_SECURITY_AUDITING },
@@ -128,6 +138,7 @@ static ServiceRole services[] = {
 	{ "nfs",                    GST_ROLE_FILE_SERVER_NFS },
 	{ "nfs-kernel-server",      GST_ROLE_FILE_SERVER_NFS },
 	{ "nfs-user-server",        GST_ROLE_FILE_SERVER_NFS },
+	{ "nginx",                  GST_ROLE_WEB_SERVER },
 	{ "nis",                    GST_ROLE_NSS },
 	{ "ntp",                    GST_ROLE_NTP_SERVER },
 	{ "ntp-server",             GST_ROLE_NTP_SERVER },
@@ -141,22 +152,29 @@ static ServiceRole services[] = {
 	{ "pbbuttonsd",             GST_ROLE_HOTKEYS_MANAGEMENT },
 	{ "portmap",                GST_ROLE_RPC_MAPPER },
 	{ "postfix",                GST_ROLE_MTA },
+	{ "postgresql",             GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-7.4",         GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-8.0",         GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-8.1",         GST_ROLE_DATABASE_SERVER },
-	{ "postgresql",             GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.2",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.3",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.4",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.5",         GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-9.0",         GST_ROLE_DATABASE_SERVER },
 	{ "powernowd",              GST_ROLE_CPUFREQ_MANAGEMENT },
 	{ "pptpd",                  GST_ROLE_VPN_SERVER },
 	{ "proftpd",                GST_ROLE_FILE_SERVER_FTP },
 	{ "pure-ftpd",              GST_ROLE_FILE_SERVER_FTP },
+	{ "rc-inetd",               GST_ROLE_NETWORK },
 	{ "qmail",                  GST_ROLE_MTA },
 	{ "quagga",                 GST_ROLE_ROUTE_SERVER },
 	{ "quota",                  GST_ROLE_QUOTA_MANAGEMENT },
 	{ "racoon",                 GST_ROLE_IPSEC_KEY_EXCHANGE_SERVER },
 	{ "radvd",                  GST_ROLE_ROUTER_ADVERTISEMENT_SERVER },
+	{ "rdate",                  GST_ROLE_NTP_SERVER },
 	{ "rgmanager",              GST_ROLE_CLUSTER_MANAGEMENT },
-	{ "rsyncd",                 GST_ROLE_REMOTE_BACKUP },
 	{ "rsync",                  GST_ROLE_REMOTE_BACKUP },
+	{ "rsyncd",                 GST_ROLE_REMOTE_BACKUP },
 	{ "samba",                  GST_ROLE_FILE_SERVER_SMB },
 	{ "schoolbell",             GST_ROLE_WEB_CALENDAR_SERVER },
 	{ "schooltool",             GST_ROLE_SCHOOL_MANAGEMENT_PLATFORM },
@@ -165,7 +183,9 @@ static ServiceRole services[] = {
 	{ "sensord",                GST_ROLE_HARDWARE_MONITORING },
 	{ "shorewall",              GST_ROLE_FIREWALL_MANAGEMENT },
 	{ "slapd",                  GST_ROLE_LDAP_SERVER },
+	{ "slim",                   GST_ROLE_DISPLAY_MANAGER },
 	{ "smartmontools",          GST_ROLE_HARDWARE_MONITORING },
+	{ "smb",                    GST_ROLE_FILE_SERVER_SMB },
 	{ "snmpd",                  GST_ROLE_SNMP_SERVER },
 	{ "spamassassin",           GST_ROLE_SPAM_FILTER },
 	{ "squid",                  GST_ROLE_PROXY_CACHE },
@@ -173,8 +193,11 @@ static ServiceRole services[] = {
 	{ "sshd",                   GST_ROLE_SECURE_SHELL_SERVER },
 	{ "sysklogd",               GST_ROLE_SYSTEM_LOGGER },
 	{ "syslog",                 GST_ROLE_SYSTEM_LOGGER },
+	{ "syslog-ng",              GST_ROLE_SYSTEM_LOGGER },
 	{ "tftpd-hpa",              GST_ROLE_FILE_SERVER_TFTP },
 	{ "vcron",                  GST_ROLE_COMMAND_SCHEDULER },
+	{ "vixie-cron",             GST_ROLE_COMMAND_SCHEDULER },
+	{ "vmware-player",          GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT },
 	{ "vsftpd",                 GST_ROLE_FILE_SERVER_FTP },
 	{ "wacom-tools",            GST_ROLE_GRAPHIC_TABLETS_MANAGEMENT },
 	{ "wdm",                    GST_ROLE_DISPLAY_MANAGER },
@@ -185,6 +208,7 @@ static ServiceRole services[] = {
 	{ "xinetd",                 GST_ROLE_NETWORK },
 	{ "zmailer",                GST_ROLE_MTA },
 	{ "zope3",                  GST_ROLE_APPLICATION_SERVER },
+	{ "NetworkManager",         GST_ROLE_NETWORK },
 };
 
 static int
