@@ -143,10 +143,10 @@ static GtkWidgetClass *parent_class;
  * Return value: The type ID of the #EMap class.
  **/
 
-GtkType
+GType
 e_map_get_type (void)
 {
-	static GtkType e_map_type = 0;
+	static GType e_map_type = 0;
 
 	if (!e_map_type)
 	{
@@ -185,7 +185,7 @@ e_map_class_init (EMapClass *class)
 	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 
-	parent_class = gtk_type_class (GTK_TYPE_WIDGET);
+	parent_class = g_type_class_peek (GTK_TYPE_WIDGET);
 
 	object_class->destroy = e_map_destroy;
 	
@@ -280,21 +280,21 @@ e_map_finalize (GObject *object)
 	view = E_MAP (object);
 	priv = view->priv;
 
-	gtk_object_unref (GTK_OBJECT (priv->hadj));
+	g_object_unref (G_OBJECT (priv->hadj));
 	priv->hadj = NULL;
 
-	gtk_object_unref (GTK_OBJECT (priv->vadj));
+	g_object_unref (G_OBJECT (priv->vadj));
 	priv->vadj = NULL;
 
 	if (priv->map_pixbuf)
 	{
-		gdk_pixbuf_unref (priv->map_pixbuf);
+		g_object_unref (priv->map_pixbuf);
 		priv->map_pixbuf = NULL;
 	}
 
 	if (priv->map_render_pixbuf)
 	{
-		gdk_pixbuf_unref (priv->map_render_pixbuf);
+		g_object_unref (priv->map_render_pixbuf);
 		priv->map_render_pixbuf = NULL;
 	}
 
@@ -534,7 +534,8 @@ e_map_set_scroll_adjustments (GtkWidget *widget, GtkAdjustment *hadj, GtkAdjustm
 	{
 		priv->hadj = hadj;
 		g_object_ref (G_OBJECT (priv->hadj));
-		gtk_object_sink (GTK_OBJECT (priv->hadj));
+		g_object_ref_sink (G_OBJECT (priv->hadj));
+		g_object_unref (G_OBJECT (priv->hadj));
 
 		priv->hadj_signal_id = g_signal_connect (G_OBJECT (priv->hadj),
 							 "value_changed",
@@ -548,7 +549,8 @@ e_map_set_scroll_adjustments (GtkWidget *widget, GtkAdjustment *hadj, GtkAdjustm
 	{
 		priv->vadj = vadj;
 		g_object_ref (G_OBJECT (priv->vadj));
-		gtk_object_sink (GTK_OBJECT (priv->vadj));
+		g_object_ref_sink (G_OBJECT (priv->vadj));
+		g_object_unref (G_OBJECT (priv->vadj));
 
 		priv->vadj_signal_id = g_signal_connect (G_OBJECT (priv->vadj),
 							 "value_changed",
@@ -993,7 +995,7 @@ load_map_background (EMap *view, gchar *name)
 /*	pb0 = tool_load_image (name);*/
 	if (!pb0) return (FALSE);
 
-	if (priv->map_pixbuf) gdk_pixbuf_unref (priv->map_pixbuf);
+	if (priv->map_pixbuf) g_object_unref (priv->map_pixbuf);
 	priv->map_pixbuf = pb0;
 	update_render_pixbuf (view, TRUE);
 
@@ -1037,7 +1039,7 @@ update_render_pixbuf (EMap *map, gboolean render_overlays)
 
 	/* Reallocate the pixbuf */
 
-	if (priv->map_render_pixbuf) gdk_pixbuf_unref (priv->map_render_pixbuf);
+	if (priv->map_render_pixbuf) g_object_unref (priv->map_render_pixbuf);
 	priv->map_render_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE,	/* No alpha */
 						  8, width, height);
 
@@ -1318,7 +1320,7 @@ scroll_to (EMap *view, int x, int y)
 
 	gdk_draw_drawable (window, gc, window, src_x, src_y, dest_x, dest_y, width - abs (xofs), height - abs (yofs));
 
-	gdk_gc_unref (gc);
+	g_object_unref (gc);
 
 	/* Add the scrolled-in region */
 
@@ -1579,7 +1581,7 @@ blowup_window_area (GdkWindow *window, gint area_x, gint area_y, gint target_x,
 
 	/* Free our GC */
 
-	gdk_gc_unref (gc);
+	g_object_unref (gc);
 }
 
 
@@ -1775,8 +1777,8 @@ set_scroll_area (EMap *view)
 	if (priv->map_render_pixbuf)
 		priv->vadj->upper = gdk_pixbuf_get_height (priv->map_render_pixbuf);
 
-	gtk_signal_emit_by_name (GTK_OBJECT (priv->hadj), "changed");
-	gtk_signal_emit_by_name (GTK_OBJECT (priv->vadj), "changed");
+	g_signal_emit_by_name(G_OBJECT(priv->hadj), "changed");
+	g_signal_emit_by_name(G_OBJECT(priv->vadj), "changed");
 
 	priv->xofs = CLAMP (priv->xofs, 0, priv->hadj->upper - priv->hadj->page_size);
 	priv->yofs = CLAMP (priv->yofs, 0, priv->vadj->upper - priv->vadj->page_size);
